==> dev-plugin-android-7.2.1-beta1-sources.jar: com/zoyi/channel/plugin/android/User.java <==
package com.zoyi.channel.plugin.android;

import android.support.annotation.Nullable;

import java.util.List;
import java.util.Map;

/**
 * @deprecated Use {@link com.zoyi.channel.plugin.android.open.model.User}
 */
@Deprecated
public class User {

  private String id;
  private String memberId;
  private String name;
  private String avatarUrl;
  private int alert;
  private Map<String, Object> profile;
  private boolean unsubscribed;
  private List<String> tags;

  @Nullable
  public static User newInstance(@Nullable com.zoyi.channel.plugin.android.model.rest.User userEntity) {
    return userEntity != null ? new User(userEntity) : null;
  }

  private User(com.zoyi.channel.plugin.android.model.rest.User user) {
    this.id = user.getId();
    this.memberId = user.getMemberId();
    this.name = user.getName();
    this.avatarUrl = user.getAvatarUrl();
    this.alert = user.getAlert();
    this.profile = user.getProfile();
    this.unsubscribed = user.getUnsubscribed();
    this.tags = user.getTags();
  }

  public User(
      String id,
      String memberId,
      String name,
      String avatarUrl,
      int alert,
      Map<String, Object> profile,
      boolean unsubscribed,
      List<String> tags
  ) {
    this.id = id;
    this.memberId = memberId;
    this.name = name;
    this.avatarUrl = avatarUrl;
    this.alert = alert;
    this.profile = profile;
    this.unsubscribed = unsubscribed;
    this.tags = tags;
  }

  public String getId() {
    return id;
  }

  public String getMemberId() {
    return memberId;
  }

  public String getName() {
    return name;
  }

  public String getAvatarUrl() {
    return avatarUrl;
  }

  public int getAlert() {
    return alert;
  }

  public Map<String, Object> getProfile() {
    return profile;
  }

  public boolean isUnsubscribed() {
    return unsubscribed;
  }

  public List<String> getTags() {
    return tags;
  }
}

==> dev-plugin-android-9.0.0+beta1-sources.jar: com/zoyi/channel/plugin/android/User.java <==
package com.zoyi.channel.plugin.android;

import androidx.annotation.Nullable;

import java.util.List;
import java.util.Map;

/**
 * @deprecated Use {@link com.zoyi.channel.plugin.android.open.model.User}
 */
@Deprecated
public class User {

  private String id;
  @Nullable
  private String memberId;
  @Nullable
  private String name;
  @Nullable
  private String avatarUrl;
  private int alert;
  @Nullable
  private Map<String, Object> profile;
  private boolean unsubscribed;
  @Nullable
  private List<String> tags;

  @Nullable
  public static User newInstance(@Nullable com.zoyi.channel.plugin.android.model.rest.User userEntity) {
    return userEntity != null ? new User(userEntity) : null;
  }

  private User(com.zoyi.channel.plugin.android.model.rest.User user) {
    this.id = user.getId();
    this.memberId = user.getMemberId();
    this.name = user.getName();
    this.avatarUrl = user.getAvatarUrl();
    this.alert = user.getAlert();
    this.profile = user.getProfile();
    this.unsubscribed = user.getUnsubscribed();
    this.tags = user.getTags();
  }

  public User(
      String id,
      @Nullable String memberId,
      @Nullable String name,
      @Nullable String avatarUrl,
      int alert,
      @Nullable Map<String, Object> profile,
      boolean unsubscribed,
      @Nullable List<String> tags
  ) {
    this.id = id;
    this.memberId = memberId;
    this.name = name;
    this.avatarUrl = avatarUrl;
    this.alert = alert;
    this.profile = profile;
    this.unsubscribed = unsubscribed;
    this.tags = tags;
  }

  public String getId() {
    return id;
  }

  @Nullable
  public String getMemberId() {
    return memberId;
  }

  @Nullable
  public String getName() {
    return name;
  }

  @Nullable
  public String getAvatarUrl() {
    return avatarUrl;
  }

  public int getAlert() {
    return alert;
  }

  @Nullable
  public Map<String, Object> getProfile() {
    return profile;
  }

  public boolean isUnsubscribed() {
    return unsubscribed;
  }

  @Nullable
  public List<String> getTags() {
    return tags;
  }
}
